<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>منتقي التطبيقات</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>اختر تطبيقا لِ‍:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>التطبيقات التي تتعامل مع JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>عنصر فرعي جديد</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>التطبيقات الأخرى</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation>متصفحات الويب</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation>عملاء البريد الإلكتروني</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation>مدراء الملفات</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation>التطبيقات الأخرى التي تتعامل مع%1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>التطبيقات التي تتعامل مع %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>لم يُعثر على أي تطبيق</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation>لم يتم العثور على المزيد من التطبيقات</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation>تغيير...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation>اختر...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>&amp;غيّر...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>ا&amp;ختر...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>ارتباطات الملفات</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation>الجمعيات</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>التطبيق المبدئي</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>ا&amp;ختر...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation>التطبيقات الافتراضية</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation>متصفح الانترنت</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation>اختر...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation>عميل البريد الإلكتروني</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation>مدير الملفات</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>الأنماط</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation>‎*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>نوع MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>الأيقونة</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
</context>
</TS>
